#
# spec file for package glmark2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015-2016 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           glmark2
Version:        0.0+git.20180208
Release:        lp151.2.4
Summary:        OpenGL 2.0 and ES 2.0 benchmark
License:        GPL-3.0-only
Group:          System/X11/Utilities
URL:            https://github.com/glmark2/glmark2
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  ImageMagick
BuildRequires:  fdupes
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  xz
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libpng16)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(x11)
# Skip wayland on SLE
%if 0%{?is_opensuse}
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-egl)
%endif
# C++14 capable compiler is required
%if 0%{?suse_version} > 1320
BuildRequires:  gcc-c++ >= 5.0
%else
BuildRequires:  gcc7-c++
%endif

%description
A benchmark for OpenGL (ES) 2.0 that uses only the OpenGL ES 2.0 compatible
API. It contains tests for standard OpenGL (ES) 2.0 features, such as vertex
arrays, VBOs, texturing and shaders.

%prep
%setup -q

%build
%if 0%{?suse_version} < 1320
export CXX=g++-7
%endif
export CXXFLAGS="%{optflags}"
python3 waf configure \
  %if 0%{?is_opensuse}
  --with-flavors=x11-gl,x11-glesv2,wayland-gl,wayland-glesv2,drm-gl,drm-glesv2 \
  %else
  --with-flavors=x11-gl,x11-glesv2,drm-gl,drm-glesv2 \
  %endif
  --prefix=%{_prefix}
python3 waf --verbose %{?_smp_mflags}

%install
python3 waf install --destdir=%{buildroot}
#FIXME Clean up runtime warning - libpng warning: iCCP: known incorrect sRGB profile
pushd %{buildroot}%{_datadir}/%{name}/textures
convert effect-2d.png -strip effect-2d.png
popd
%fdupes -s %{buildroot}

%files
%license COPYING COPYING.SGI
%doc NEWS
%{_bindir}/glmark2
%{_bindir}/glmark2-drm
%{_bindir}/glmark2-es2
%{_bindir}/glmark2-es2-drm
%if 0%{?is_opensuse}
%{_bindir}/glmark2-es2-wayland
%{_bindir}/glmark2-wayland
%endif
%{_datadir}/%{name}
%{_mandir}/man1/glmark2.1%{?ext_man}
%{_mandir}/man1/glmark2-drm.1%{?ext_man}
%{_mandir}/man1/glmark2-es2.1%{?ext_man}
%{_mandir}/man1/glmark2-es2-drm.1%{?ext_man}
%if 0%{?is_opensuse}
%{_mandir}/man1/glmark2-es2-wayland.1%{?ext_man}
%{_mandir}/man1/glmark2-wayland.1%{?ext_man}
%endif

%changelog
* Thu Mar  8 2018 mpluskal@suse.com
- Update to version 0.0+git.20180208:
  * Allow to limit to a number of frames
  * Build: Exclude dispmanx-glesv2 when building 'all' flavors
  * Port glmark2 to Raspberry Pi's dispmanx.
  * Include a PFNEGLGETPLATFORMDISPLAYEXTPROC typedef for older eglext.h.
  * Mesh: Improve performance of Mesh::update_single_array
  * textures: Fix libpng 1.6 invalid color profile warning
  * NativeStateDRM: fix running without current mode
  * libmatrix: Remove deprecated dynamic exception specifications
  * ShaderSource: Fix clang warning autological-unsigned-zero-compare
* Fri Oct  6 2017 mpluskal@suse.com
- Update to version 0.0+git.20170908:
  * Build,Doc: Update files for 2017.07 release
  * NativeStateDRM: Be explicit about the drmEventContext version we use
  * Fix clang warnings
  * SceneTerrain: Fix off-by-one error in array size
* Fri Jul 28 2017 mpluskal@suse.com
- Update to version 0.0+git.20170713:
  * NativeStateDRM: add imx-drm driver support
  * drm: Add the pl111 and vc4 drm drivers
  * drm: Initialize the page flip handler to 0.
  * SceneTerrain: Add missing header file for std::abs
  * wayland: Fix destruction order of surface-related objects
  * wayland: Don't store the opaque region unnecessarily
  * GLStateEGL: Use eglGetPlatformDisplayEXT when possible
  * NativeStateDRM: Probe the DRM node path to use with udev
* Tue Feb 14 2017 mpluskal@suse.com
- Update to version 0.0+git.20170210:
  * Use monotonic clock
* Sun Jan 22 2017 mpluskal@suse.com
- Packaging changes:
  * Fix building on SLES and Leap
  * Enable parallel build
* Sun Nov 13 2016 mpluskal@suse.com
- Update to version 0.0+git.20160914:
  * Build: Update to waf 1.9.3 and unpack as required by debian policy
  * Build: Remove -Werror from the default build flags
  * Fix C++11 build error
  * Build: Build in c++14 mode
  * wscript: check C libraries using the C compiler
  * Do not use deprecated std::auto_ptr
  * NativeStateWayland: Fix segfault during teardown when failing to connect to wayland compositor
  * NativeStateMir: Fix compilation with c++11/14
  * Build: Don't rebuild common sources needlessly
  * data: Remove unused uniforms from shaders
- Drop upstreamed glmark2-drop-sqrt-check.patch
- Switch versioning to more reasonable one
* Tue Jul 26 2016 mpluskal@suse.com
- Update to version 2014.03+git.20150611:
  * Build: Correct dependencies on matrix-glesv2 target
  * NativeStateX11: Don't terminate --fullscreen if EWMH Atom not found
  * libpng: Allow compilation in C++11 mode
  * Build,Doc: Update files for 2014.03 release
  * Build: Support libpng 1.6
  * NativeStateMir: Update for newest Mir client API
  * Fix clang build errors
  * Build: Exclude git repository files from dist tarball
  * Build: Allow user defined CXXFLAGS to override all built-in flags
  * Build: Allow disabling the -Werror compiler flag
- Add _service
- Some spec file cleanups
* Sun Jul 17 2016 malcolmlewis@opensuse.org
- Add glmark2-drop-sqrt-check.patch: Add upstream patch to drop
  sqrt check. See https://github.com/glmark2/glmark2/issues/15.
- Add CXXFLAGS no-deprecated-declarations and no-werror option to
  build. See https://github.com/glmark2/glmark2/issues/20.
* Fri Oct  9 2015 malcolmlewis@opensuse.org
- Clean up runtime warning - libpng warning: iCCP: known incorrect
  sRGB profile.
* Thu Oct  8 2015 malcolmlewis@opensuse.org
- Initial build.
